pub enum TokenPermissions {
Allowance,
Balance,
History,
Owner,
}Variants
Allowance
Allowance for SNIP-20 - Permission to query allowance of the owner & spender
Balance
Balance for SNIP-20 - Permission to query balance
History
History for SNIP-20 - Permission to query transfer_history & transaction_hisotry
Owner
Owner permission indicates that the bearer of this permit should be granted all the access of the creator/signer of the permit. SNIP-721 uses this to grant viewing access to all data that the permit creator owns and is whitelisted for. For SNIP-721 use, a permit with Owner permission should NEVER be given to anyone else. If someone wants to share private data, they should whitelist the address they want to share with via a SetWhitelistedApproval tx, and that address will view the data by creating their own permit with Owner permission