pub struct PermitSignature {
pub pub_key: PubKey,
pub signature: Binary,
}Fields
pub_key: PubKeysignature: BinaryTrait Implementations
Sourceimpl Clone for PermitSignature
impl Clone for PermitSignature
Sourcefn clone(&self) -> PermitSignature
fn clone(&self) -> PermitSignature
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PermitSignature
impl Debug for PermitSignature
Sourceimpl<'de> Deserialize<'de> for PermitSignature
impl<'de> Deserialize<'de> for PermitSignature
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for PermitSignature
impl JsonSchema for PermitSignature
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn json_schema(gen: &mut SchemaGenerator) -> Schema
fn json_schema(gen: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for PermitSignature
impl PartialEq for PermitSignature
Sourcefn eq(&self, other: &PermitSignature) -> bool
fn eq(&self, other: &PermitSignature) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for PermitSignature
impl Serialize for PermitSignature
impl StructuralPartialEq for PermitSignature